from setuptools import setup, find_packages

setup(
    name="VeryEasyAI",
    version="1.1.0",
    description="Uma biblioteca de IA super simples e fácil de usar",
    author="Enzo DEV",
    packages=find_packages(),
    install_requires=["requests"],
    python_requires=">=3.8",
)
